var Megamenu_framework_persistant_state = {index:-1, active:0};
(function ($) {
    Drupal.behaviors.megamenu_framework = {
        attach: function (context, settings) {
            // BEGIN document ready

            // Hover actions on the main menu items.
            $('#block-megamenu-framework-megamenu-framework div.mainmenu-item').mouseover(function(e) {
                $(this).addClass('hover');
            });
            $('#block-megamenu-framework-megamenu-framework div.mainmenu-item').mouseout(function(e) {
                $(this).removeClass('hover');
            });

            if (Drupal.settings.megamenu_framework != undefined) {
                if (Drupal.settings.megamenu_framework.eventType == 'click') {
                    // Activation of menu pulldowns (click event)
                    $('#block-megamenu-framework-megamenu-framework div.mainmenu-item').click(function(e) {

                        var megamenu_items= $('#block-megamenu-framework-megamenu-framework div.mainmenu-item');
                        var id = 'megamenu-framework-pulldown-' + $(this).attr('title');

                        // Clean up previous states
                        $('#block-megamenu-framework-megamenu-framework .megamenu-pulldown-wrapper').not(document.getElementById(id)).hide();
                        megamenu_items.removeClass('active');

                        /*
                         Activate the pulldown
                         jQuery's hasClass() method does not work on dynamically created classes, so toggling the "active" class is not so simple
                         We have to store the state of this class in a persistent variable (Global variable declared at the top of this script.
                         We start by capturing the index of the clicked menu item
                         */
                        var target_megamenu_item = $(this);
                        var megamenu_active_index = megamenu_items.index(target_megamenu_item);

                        /*
                         We store the index and the active state in that variable on click events
                         And test it against the clicked item to determine if we're adding or removing the active state.
                         If the stored index and the clicked index match, then we're clicking on an active button (thereby toggling it off).
                         Therefore we remove the "active" class
                         Otherwise we add the class.
                         */
                        if (Megamenu_framework_persistant_state.index == megamenu_active_index) {
                            $(this).removeClass('active');
                            Megamenu_framework_persistant_state.active = 0; // off
                            Megamenu_framework_persistant_state.index = -1; // no index
                        }
                        else {
                            $(this).addClass('active');
                            Megamenu_framework_persistant_state.active = 1; // On
                            Megamenu_framework_persistant_state.index = megamenu_active_index; // index of clicked object
                        }
                        // Toggle the visibility of the pulldown
                        $('#block-megamenu-framework-megamenu-framework #' + id).toggle();

                        // None of this works at all without this call.
                        e.stopPropagation();
                    });

                    // Clicking ANYWHERE, other than the main menu items closes the menu.
                    $('html').click(function() {
                        $('#block-megamenu-framework-megamenu-framework .megamenu-pulldown-wrapper').hide();
                        $('#block-megamenu-framework-megamenu-framework div.mainmenu-item').removeClass('active');
                        Megamenu_framework_persistant_state.active = 0;
                        Megamenu_framework_persistant_state.index = -1;
                    });

                    // Exceptions to the above operation. jQuery selectors for this are entered in the module's ui.
                    if (Drupal.settings.megamenu_framework.stopPropagations != undefined) {
                        $(Drupal.settings.megamenu_framework.stopPropagations).click(function(e){
                            e.stopPropagation();
                        });
                    }
                }
                else {
                    // Activate pulldowns on hover event
                    $('#block-megamenu-framework-megamenu-framework div.mainmenu-item').hover(
                        function(e) {
                            var megamenu_items= $('#block-megamenu-framework-megamenu-framework div.mainmenu-item');
                            var id = 'megamenu-framework-pulldown-' + $(this).attr('title');

                            // Initialize by closing all the pulldowns
                            $('#block-megamenu-framework-megamenu-framework .megamenu-pulldown-wrapper').hide();

                            // Activate the target pulldown
                            var openPulldownTimeoutID = window.setTimeout(
                                openPulldown,
                                100,
                                id
                            );

                        }, function(e) {
                            /*
                             Close when rolling off of a menu item
                             We pass in a jquery id for any pulldown hover event.
                             The prevents the pulldown from closing when we roll from a menu item to its pulldown.
                             */
                            var closePulldownTimeoutID = window.setTimeout(
                                closePulldown,
                                100,
                                '#block-megamenu-framework-megamenu-framework .megamenu-pulldown-wrapper:hover'
                            );
                        }
                    );

                    // Close when rolling off the pulldown.
                    $('#block-megamenu-framework-megamenu-framework .megamenu-pulldown-wrapper').mouseleave(function(e) {
                        var closePulldownTimeoutID = window.setTimeout(
                            closePulldown,
                            100
                        );
                    });
                }
            }

            
            /**
            A plugin for setting active-trail class on a main menu item.
            Arg: index = the 0 based index of the main menu item you want to set.
            Usage: $(document).megamenu_framework_set_active_trail(index);
               
            Calculating the index is beyond the scope of this module. You'll have to do that yourself.
            */
            $.fn.megamenu_framework_set_active_trail = function(index) {
                $('#block-megamenu-framework-megamenu-framework div.mainmenu-item:eq(' + index + ')').each(function() {
                    $(this).addClass('active-trail');
                });
            };

            function openPulldown(id) {
                $('#block-megamenu-framework-megamenu-framework #' + id).show();
            }

            /**
             @param jqueryTestString (optional)
             We pass in a jquery ID string to test for a hover state on ANY pulldown.
             We only close the pulldown if that tests false. This prevents the popup from closing when we roll off a main menu item
             onto its pulldown.
             
             If we don't pass in an argument, it closes all pulldowns by default. This gets called when we roll off a pulldown
             */
            function closePulldown(jqueryTestString) {
                if (jqueryTestString != undefined) {
                    if (!$(jqueryTestString).length) {
                        // Rolling off of menu item: close all pulldowns
                        // Rolling onto another will open a new one
                        $('#block-megamenu-framework-megamenu-framework .megamenu-pulldown-wrapper').hide();
                    }
                }
                else {
                    // Rolling off of a pulldown: close all pulldowns
                    $('#block-megamenu-framework-megamenu-framework .megamenu-pulldown-wrapper').hide();
                }
            }

            // END document ready
        }
    };
})(jQuery);